
// GetPeakValuesDlg.cpp : implementation file
//

#include "stdafx.h"
#include "GetPeakValues.h"
#include "GetPeakValuesDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif


#define ID_MY_TIMER  101

CGetPeakValuesDlg::CGetPeakValuesDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CGetPeakValuesDlg::IDD, pParent)
{
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);

	m_SP = NULL;
}

void CGetPeakValuesDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);

	DDX_Control(pDX, IDC_START_HZ, m_EDStartHz);
	DDX_Control(pDX, IDC_STOP_HZ, m_EDStopHz);
	DDX_Control(pDX, IDC_FREQ_0, m_EDFreq_0);
	DDX_Control(pDX, IDC_FREQ_1, m_EDFreq_1);
	DDX_Control(pDX, IDC_FREQ_2, m_EDFreq_2);
	DDX_Control(pDX, IDC_FREQ_3, m_EDFreq_3);
	DDX_Control(pDX, IDC_LEVEL_0, m_EDLevel_0);
	DDX_Control(pDX, IDC_LEVEL_1, m_EDLevel_1);
	DDX_Control(pDX, IDC_LEVEL_2, m_EDLevel_2);
	DDX_Control(pDX, IDC_LEVEL_3, m_EDLevel_3);
	DDX_Control(pDX, IDC_PEAK_NUMBER, m_CBPeakNumber);
}

BEGIN_MESSAGE_MAP(CGetPeakValuesDlg, CDialog)
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	//}}AFX_MSG_MAP
	ON_BN_CLICKED(IDC_OPEN, &CGetPeakValuesDlg::OnBnClickedOpen)
	ON_BN_CLICKED(IDC_RUN, &CGetPeakValuesDlg::OnBnClickedRun)
	ON_BN_CLICKED(IDC_STOP, &CGetPeakValuesDlg::OnBnClickedStop)
	ON_EN_CHANGE(IDC_START_HZ, &CGetPeakValuesDlg::OnEnChangeStartHz)
	ON_EN_CHANGE(IDC_STOP_HZ, &CGetPeakValuesDlg::OnEnChangeStopHz)
	ON_CBN_SELCHANGE(IDC_PEAK_NUMBER, &CGetPeakValuesDlg::OnSelChangePeakNumber)
	ON_WM_TIMER()
	ON_WM_CLOSE()
END_MESSAGE_MAP()


// CGetPeakValuesDlg message handlers

BOOL CGetPeakValuesDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	CoInitialize(NULL);

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon

	m_EDStartHz.SetWindowText("500.0");
	m_EDStopHz.SetWindowText("5000.0");

	// populate the peak number combobox
	for (int n=0; n<10; n++)
	{
		CString szPeak;
		szPeak.Format("%d", n+1);    // peak numbers for the API are zero based - show 1 based numbers to the user
		m_CBPeakNumber.AddString(szPeak);
		m_CBPeakNumber.SetItemData(n, n); 
	}
	m_CBPeakNumber.SetCurSel(0);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

// If you add a minimize button to your dialog, you will need the code below
//  to draw the icon.  For MFC applications using the document/view model,
//  this is automatically done for you by the framework.

void CGetPeakValuesDlg::OnPaint()
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, reinterpret_cast<WPARAM>(dc.GetSafeHdc()), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialog::OnPaint();
	}
}

// The system calls this function to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CGetPeakValuesDlg::OnQueryDragIcon()
{
	return static_cast<HCURSOR>(m_hIcon);
}



//------------------------------------------------
void CGetPeakValuesDlg::OnBnClickedOpen()
{
	if ( m_SP == NULL)
	{
		m_SP.CreateInstance( __uuidof(SpectraPLUS_DTClass) );
	}

	if ( m_SP == NULL)
	{
		MessageBox("Failure opening SpectraPLUS-DT.", AfxGetAppName(), MB_ICONSTOP);
		return;
	}


	// NOTE - Using a config file with SpectraPLUS-DT is highly recommended
	// m_SP->LoadConfig("C:\\SpectraPLUS_DT\\Config\\test2.cfg");

	m_SP->SetMode(0);  // Realtime
	m_SP->ChannelEnable(0);
	m_SP->ChannelEnable(1);
	m_SP->ChannelEnable(2);
	m_SP->ChannelEnable(3);


}

//------------------------------------------------
void CGetPeakValuesDlg::OnClose()
{
	KillTimer( ID_MY_TIMER );

	if ( m_SP == NULL)
	{
		m_SP = NULL;  // smart pointer - handles itself
	}

	CDialog::OnClose();
}

//------------------------------------------------
void CGetPeakValuesDlg::OnBnClickedRun()
{
	if ( m_SP == NULL)
	{
		MessageBox("SpectraPLUS-DT is not open", AfxGetAppName(), MB_ICONSTOP);
		return;
	}

	m_SP->Run();

	KillTimer( ID_MY_TIMER );
	SetTimer( ID_MY_TIMER, 500, NULL );  // 500 msec update rate
}

//------------------------------------------------
void CGetPeakValuesDlg::OnBnClickedStop()
{
	KillTimer( ID_MY_TIMER );

	if ( m_SP == NULL)
	{
		MessageBox("SpectraPLUS-DT is not open", AfxGetAppName(), MB_ICONSTOP);
		return;
	}

	m_SP->Stop();
}

//------------------------------------------------
void CGetPeakValuesDlg::OnEnChangeStartHz()
{
	GetResults();
}

//------------------------------------------------
void CGetPeakValuesDlg::OnEnChangeStopHz()
{
	GetResults();
}

//------------------------------------------------
void CGetPeakValuesDlg::OnSelChangePeakNumber()
{
	GetResults();
}

//------------------------------------------------
void CGetPeakValuesDlg::OnTimer(UINT_PTR nIDEvent)
{
	CDialog::OnTimer(nIDEvent);

	GetResults();
}


//------------------------------------------------
void CGetPeakValuesDlg::GetResults()
{
	if ( m_SP == NULL) return;

	CString szStart;
	m_EDStartHz.GetWindowText(szStart);
	float startHz = atof(szStart);

	CString szStop;
	m_EDStopHz.GetWindowText(szStop);
	float stopHz = atof(szStop);

	int peak_number = m_CBPeakNumber.GetItemData(m_CBPeakNumber.GetCurSel());

	try
	{
		CString szFreq;

		float pk_freq = 0.0;
		m_SP->GetPeakFrequencyNthSpan(0, peak_number, startHz, stopHz, &pk_freq);
		szFreq.Format("%f", pk_freq);
		m_EDFreq_0.SetWindowText(szFreq);

		pk_freq = 0.0;
		m_SP->GetPeakFrequencyNthSpan(1, peak_number, startHz, stopHz, &pk_freq);
		szFreq.Format("%f", pk_freq);
		m_EDFreq_1.SetWindowText(szFreq);

		pk_freq = 0.0;
		m_SP->GetPeakFrequencyNthSpan(2, peak_number, startHz, stopHz, &pk_freq);
		szFreq.Format("%f", pk_freq);
		m_EDFreq_2.SetWindowText(szFreq);

		pk_freq = 0.0;
		m_SP->GetPeakFrequencyNthSpan(3, peak_number, startHz, stopHz, &pk_freq);
		szFreq.Format("%f", pk_freq);
		m_EDFreq_3.SetWindowText(szFreq);


		CString szLevel;

		float pk_level = 0.0;
		m_SP->GetPeakAmplitudeNthSpan(0, peak_number, startHz, stopHz, &pk_level);
		szLevel.Format("%f", pk_level);
		m_EDLevel_0.SetWindowText(szLevel);

		pk_level = 0.0;
		m_SP->GetPeakAmplitudeNthSpan(1, peak_number, startHz, stopHz, &pk_level);
		szLevel.Format("%f", pk_level);
		m_EDLevel_1.SetWindowText(szLevel);

		pk_level = 0.0;
		m_SP->GetPeakAmplitudeNthSpan(2, peak_number, startHz, stopHz, &pk_level);
		szLevel.Format("%f", pk_level);
		m_EDLevel_2.SetWindowText(szLevel);

		pk_level = 0.0;
		m_SP->GetPeakAmplitudeNthSpan(3, peak_number, startHz, stopHz, &pk_level);
		szLevel.Format("%f", pk_level);
		m_EDLevel_3.SetWindowText(szLevel);

	}
	catch ( _com_error &error )
	{
		KillTimer( ID_MY_TIMER );
		MessageBox( error.ErrorMessage() );
	}
	
}
